@@ -1,4 +1,4 @@
-#!C:\bld\qds-sdk_1498449821918\_b_env\python.exe
+#!C:\bld\qds-sdk_1504408165235\_b_env\python.exe
 
 from __future__ import print_function
 from qds_sdk.commands import *
@@ -473,7 +473,7 @@ def clustermain(args, api_version):
 def clustermainv2(args):
     action = args[0]
     actionset = set(
-        ["create", "delete", "update", "clone", "list", "start", "terminate", "status", "reassign_label", "add_node",
+        ["create", "delete", "update", "list", "clone", "start", "terminate", "status", "reassign_label", "add_node",
          "remove_node", "update_node", "snapshot", "restore_point", "get_snapshot_schedule",
          "update_snapshot_schedule"])
 
@@ -481,7 +481,7 @@ def clustermainv2(args):
     if action not in actionset:
         sys.stderr.write("action must be one of <%s>\n" % "|".join(actionset))
         usage()
-    elif action in set(["create", "update", "clone"]):
+    elif action in set(["create", "update", "clone", "list"]):
         result =  ClusterCmdLine.run(args)
     else:
         result =  globals()["cluster_" + action + "_action"](Cluster, args)
@@ -558,7 +558,7 @@ def main():
 
     optparser.add_option("--cloud_name", dest="cloud_name",
                          default=os.getenv('CLOUD_PROVIDER'),
-                         help="cloud", choices=["AWS", "AZURE", "ORACLE_BMC"])
+                         help="cloud", choices=["AWS", "AZURE", "ORACLE_BMC", "ORACLE_OPC"])
 
     optparser.add_option("-v", dest="verbose", action="store_true",
                          default=False,
