@@ -96,8 +96,8 @@ class Qubole:
 
     @classmethod
     def get_cloud(cls, cloud_name=None):
-        if cloud_name and cloud_name.lower() not in ["aws", "oracle_bmc", "azure"]:
-            raise Exception("cloud should be 'aws', 'oracle_bmc' or 'azure'")
+        if cloud_name and cloud_name.lower() not in ["aws", "oracle_bmc", "azure", "oracle_opc"]:
+            raise Exception("cloud should be 'aws', 'oracle_bmc', 'azure' or 'oracle_opc'")
 
         if cloud_name:
             return Qubole.get_cloud_object(cloud_name)
@@ -116,4 +116,7 @@ class Qubole:
             return qds_sdk.cloud.oracle_bmc_cloud.OracleBmcCloud()
         elif cloud_name.lower()  == "azure":
             import qds_sdk.cloud.azure_cloud
-            return qds_sdk.cloud.azure_cloud.AzureCloud()
\ No newline at end of file
+            return qds_sdk.cloud.azure_cloud.AzureCloud()
+        elif cloud_name.lower()  == "oracle_opc":
+            import qds_sdk.cloud.oracle_opc_cloud
+            return qds_sdk.cloud.oracle_opc_cloud.OracleOpcCloud()   
\ No newline at end of file
